@@ -10,16 +10,17 @@
 # accordance with the commercial license agreement provided with the
 # Software or, alternatively, in accordance with the terms contained in
 # a written agreement between you and Digia.  For licensing terms and
-# conditions see http://qt.digia.com/licensing.  For further information
-# use the contact form at http://qt.digia.com/contact-us.
+# conditions see http://www.qt.io/licensing.  For further information
+# use the contact form at http://www.qt.io/contact-us.
 #
 # GNU Lesser General Public License Usage
 # Alternatively, this file may be used under the terms of the GNU Lesser
-# General Public License version 2.1 as published by the Free Software
-# Foundation and appearing in the file LICENSE.LGPL included in the
-# packaging of this file.  Please review the following information to
-# ensure the GNU Lesser General Public License version 2.1 requirements
-# will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+# General Public License version 2.1 or version 3 as published by the Free
+# Software Foundation and appearing in the file LICENSE.LGPLv21 and
+# LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+# following information to ensure the GNU Lesser General Public License
+# requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+# http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 #
 # In addition, as a special exception, Digia gives you certain additional
 # rights.  These rights are described in the Digia Qt LGPL Exception
@@ -47,6 +48,7 @@ from stdtypes import *
 from misctypes import *
 from boosttypes import *
 from creatortypes import *
+from personaltypes import *
 
 lldbCmd = 'lldb'
 if len(sys.argv) > 1:
@@ -261,11 +263,8 @@ class Dumper(DumperBase):
         self.typeformats = {}
 
         self.currentIName = None
-        self.currentValuePriority = -100
-        self.currentValueEncoding = None
-        self.currentType = ""
-        self.currentTypePriority = -100
-        self.currentValue = None
+        self.currentValue = ReportItem()
+        self.currentType = ReportItem()
         self.currentNumChild = None
         self.currentMaxNumChild = None
         self.currentPrintsAddress = None
@@ -310,15 +309,10 @@ class Dumper(DumperBase):
             self.put('name="%s",' % item.name)
         item.savedIName = self.currentIName
         item.savedValue = self.currentValue
-        item.savedValuePriority = self.currentValuePriority
-        item.savedValueEncoding = self.currentValueEncoding
         item.savedType = self.currentType
-        item.savedTypePriority = self.currentTypePriority
         self.currentIName = item.iname
-        self.currentValuePriority = -100
-        self.currentValueEncoding = None
-        self.currentType = ""
-        self.currentTypePriority = -100
+        self.currentValue = ReportItem()
+        self.currentType = ReportItem()
 
     def exitSubItem(self, item, exType, exValue, exTraceBack):
         if not exType is None:
@@ -327,24 +321,24 @@ class Dumper(DumperBase):
             self.putNumChild(0)
             self.putValue("<not accessible>")
         try:
-            typeName = self.currentType
-            if len(typeName) > 0 and typeName != self.currentChildType:
-                self.put('type="%s",' % typeName) # str(type.unqualified()) ?
-            if  self.currentValue is None:
+            if self.currentType.value:
+                typeName = self.currentType.value
+                if len(typeName) > 0 and typeName != self.currentChildType:
+                    self.put('type="%s",' % typeName) # str(type.unqualified()) ?
+            if  self.currentValue.value is None:
                 self.put('value="<not accessible>",numchild="0",')
             else:
-                if not self.currentValueEncoding is None:
-                    self.put('valueencoded="%s",' % self.currentValueEncoding)
-                self.put('value="%s",' % self.currentValue)
+                if not self.currentValue.encoding is None:
+                    self.put('valueencoded="%s",' % self.currentValue.encoding)
+                if self.currentValue.elided:
+                    self.put('valueelided="%s",' % self.currentValue.elided)
+                self.put('value="%s",' % self.currentValue.value)
         except:
             pass
         self.put('},')
         self.currentIName = item.savedIName
         self.currentValue = item.savedValue
-        self.currentValuePriority = item.savedValuePriority
-        self.currentValueEncoding = item.savedValueEncoding
         self.currentType = item.savedType
-        self.currentTypePriority = item.savedTypePriority
         return True
 
     def isSimpleType(self, typeobj):
@@ -600,15 +594,6 @@ class Dumper(DumperBase):
                     return Hex2EncodedInt8
         return None
 
-    def putArrayData(self, type, base, n,
-            childNumChild = None, maxNumChild = 10000):
-        if not self.tryPutArrayContents(type, base, n):
-            base = self.createPointerValue(base, type)
-            with Children(self, n, type, childNumChild, maxNumChild,
-                    base, type.GetByteSize()):
-                for i in self.childRange():
-                    self.putSubItem(i, (base + i).dereference())
-
     def createPointerValue(self, address, pointeeType):
         addr = int(address) & 0xFFFFFFFFFFFFFFFF
         return self.context.CreateValueFromAddress(None, addr, pointeeType).AddressOf()
@@ -681,10 +666,11 @@ class Dumper(DumperBase):
         self.report('state="%s",msg="%s",exe="%s"' % (state, error, self.executable_))
 
     def runEngine(self, _):
+        self.prepare()
         s = threading.Thread(target=self.loop, args=[])
         s.start()
 
-    def loop(self):
+    def prepare(self):
         error = lldb.SBError()
         listener = self.debugger.GetListener()
 
@@ -699,12 +685,13 @@ class Dumper(DumperBase):
             # and later detects that it did stop after all, so it is be
             # better to mirror that and wait for the spontaneous stop.
             self.reportState("enginerunandinferiorrunok")
-        elif len(self.remoteChannel_) > 0:
+        elif self.startMode_ == AttachToRemoteServer or self.startMode_ == AttachToRemoteProcess:
             self.process = self.target.ConnectRemote(
-            self.debugger.GetListener(),
-            self.remoteChannel_, None, error)
+                self.debugger.GetListener(),
+                self.remoteChannel_, None, error)
             if not error.Success():
-                self.reportState("inferiorrunfailed")
+                self.reportError(error)
+                self.reportState("enginerunfailed")
                 return
             # Even if it stops it seems that LLDB assumes it is running
             # and later detects that it did stop after all, so it is be
@@ -725,7 +712,9 @@ class Dumper(DumperBase):
             self.report('pid="%s"' % self.process.GetProcessID())
             self.reportState("enginerunandinferiorrunok")
 
+    def loop(self):
         event = lldb.SBEvent()
+        listener = self.debugger.GetListener()
         while True:
             if listener.WaitForEvent(10000000, event):
                 self.handleEvent(event)
@@ -865,14 +854,6 @@ class Dumper(DumperBase):
     def reportStackTop(self):
         self.report('stack-top={}')
 
-    def putBetterType(self, type):
-        try:
-            self.currentType = type.GetName()
-        except:
-            self.currentType = str(type)
-        self.currentTypePriority = self.currentTypePriority + 1
-        #warn("BETTER TYPE: %s PRIORITY: %s" % (type, self.currentTypePriority))
-
     def extractBlob(self, base, size):
         if size == 0:
             return Blob("")
@@ -902,7 +883,7 @@ class Dumper(DumperBase):
         return self.target.FindFirstGlobalVariable(symbolName)
 
     def stripNamespaceFromType(self, typeName):
-        #type = stripClassTag(typeName)
+        #type = self.stripClassTag(typeName)
         type = typeName
         ns = self.qtNamespace()
         if len(ns) > 0 and type.startswith(ns):
@@ -1162,19 +1143,7 @@ class Dumper(DumperBase):
             # could be 'watch.0' or 'tooltip.deadbead'
             (base, component) = iname.split('.')
             exp = self.hexdecode(watcher['exp'])
-            if exp == "":
-                self.put('type="",value="",exp=""')
-                continue
-
-            options = lldb.SBExpressionOptions()
-            value = self.target.EvaluateExpression(exp, options)
-            #value = self.target.EvaluateExpression(iname, exp)
-            self.currentIName = base
-            with SubItem(self, component):
-                self.put('exp="%s",' % exp)
-                self.put('wname="%s",' % self.hexencode(exp))
-                self.put('iname="%s",' % iname)
-                self.putItem(value)
+            self.handleWatch(exp, exp, iname)
 
         self.put(']')
 
@@ -1232,6 +1201,9 @@ class Dumper(DumperBase):
         else:
             error = self.process.Continue()
             self.reportError(error)
+            # Happens when attaching to GDBserver.
+            if not error.Success():
+                self.reportState("inferiorill")
 
     def quitDebugger(self, _ = None):
         self.reportState("inferiorshutdownrequested")
@@ -1488,7 +1460,13 @@ class Dumper(DumperBase):
 
     def shutdownInferior(self, _ = None):
         self.isShuttingDown_ = True
-        self.process.Kill()
+        if self.process is None:
+            self.reportState("inferiorshutdownok")
+        else:
+            state = self.process.GetState()
+            if state == lldb.eStateStopped:
+                self.process.Kill()
+            self.reportState("inferiorshutdownok")
 
     def quit(self, _ = None):
         self.reportState("engineshutdownok")
@@ -1588,6 +1566,17 @@ class Dumper(DumperBase):
             self.passExceptions = int(args['passexceptions'])
         if 'watchers' in args:
             self.currentWatchers = args['watchers']
+        if 'typeformats' in args:
+            for f in args['typeformats'].split(','):
+                pos = f.find("=")
+                if pos != -1:
+                    typeName = self.hexdecode(f[0:pos])
+                    self.typeformats[typeName] = int(f[pos+1:])
+        if 'formats' in args:
+            for f in args['formats'].split(','):
+                pos = f.find("=")
+                if pos != -1:
+                    self.formats[f[0:pos]] = int(f[pos+1:])
         self.reportVariables(args)
 
     def disassemble(self, args):
