@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -38,7 +39,6 @@
 #include "qmljsconstants.h"
 
 #include <QDir>
-#include <QDebug>
 
 using namespace LanguageUtils;
 using namespace QmlJS;
@@ -148,10 +148,14 @@ Link::Link(const Snapshot &snapshot, const ViewerContext &vContext, const Librar
     ModelManagerInterface *modelManager = ModelManagerInterface::instance();
     if (modelManager) {
         ModelManagerInterface::CppDataHash cppDataHash = modelManager->cppData();
-
-        // populate engine with types from C++
-        foreach (const ModelManagerInterface::CppData &cppData, cppDataHash) {
-            d->valueOwner->cppQmlTypes().load(cppData.exportedTypes);
+        {
+            // populate engine with types from C++
+            ModelManagerInterface::CppDataHashIterator cppDataHashIterator(cppDataHash);
+            while (cppDataHashIterator.hasNext()) {
+                cppDataHashIterator.next();
+                d->valueOwner->cppQmlTypes().load(cppDataHashIterator.key(),
+                                                  cppDataHashIterator.value().exportedTypes);
+            }
         }
 
         // build an object with the context properties from C++
@@ -198,13 +202,13 @@ Context::ImportsPerDocument LinkPrivate::linkImports()
     // load builtin objects
     if (builtins.pluginTypeInfoStatus() == LibraryInfo::DumpDone
             || builtins.pluginTypeInfoStatus() == LibraryInfo::TypeInfoFileDone) {
-        valueOwner->cppQmlTypes().load(builtins.metaObjects());
+        valueOwner->cppQmlTypes().load(QLatin1String("<builtins>"), builtins.metaObjects());
     } else {
-        valueOwner->cppQmlTypes().load(CppQmlTypesLoader::defaultQtObjects);
+        valueOwner->cppQmlTypes().load(QLatin1String("<defaults>"), CppQmlTypesLoader::defaultQtObjects);
     }
 
     // load library objects shipped with Creator
-    valueOwner->cppQmlTypes().load(CppQmlTypesLoader::defaultLibraryObjects);
+    valueOwner->cppQmlTypes().load(QLatin1String("<defaultQt4>"), CppQmlTypesLoader::defaultLibraryObjects);
 
     if (document) {
         // do it on document first, to make sure import errors are shown
@@ -435,15 +439,21 @@ Import LinkPrivate::importNonFile(Document::Ptr doc, const ImportInfo &importInf
 }
 
 bool LinkPrivate::importLibrary(Document::Ptr doc,
-                         const QString &libraryPath,
+                         const QString &libraryPath_,
                          Import *import,
                          const QString &importPath)
 {
     const ImportInfo &importInfo = import->info;
+    QString libraryPath = libraryPath_;
 
-    const LibraryInfo libraryInfo = snapshot.libraryInfo(libraryPath);
-    if (!libraryInfo.isValid())
-        return false;
+    LibraryInfo libraryInfo = snapshot.libraryInfo(libraryPath);
+    if (!libraryInfo.isValid()) {
+        // try canonical path
+        libraryPath = QFileInfo(libraryPath).canonicalFilePath();
+        libraryInfo = snapshot.libraryInfo(libraryPath);
+        if (!libraryInfo.isValid())
+            return false;
+    }
 
     import->libraryPath = libraryPath;
 
@@ -484,7 +494,7 @@ bool LinkPrivate::importLibrary(Document::Ptr doc,
             }
         } else {
             const QString packageName = importInfo.name();
-            valueOwner->cppQmlTypes().load(libraryInfo.metaObjects(), packageName);
+            valueOwner->cppQmlTypes().load(libraryPath, libraryInfo.metaObjects(), packageName);
             foreach (const CppComponentValue *object, valueOwner->cppQmlTypes().createObjectsForImport(packageName, version)) {
                 import->object->setMember(object->className(), object);
             }
@@ -548,7 +558,7 @@ void LinkPrivate::loadQmldirComponents(ObjectValue *import, ComponentVersion ver
 
         importedTypes.insert(component.typeName);
         if (Document::Ptr importedDoc = snapshot.document(
-                    libraryPath + QDir::separator() + component.fileName)) {
+                    libraryPath + QLatin1Char('/') + component.fileName)) {
             if (ObjectValue *v = importedDoc->bind()->rootObjectValue())
                 import->setMember(component.typeName, v);
         }
@@ -579,7 +589,7 @@ void LinkPrivate::loadImplicitDefaultImports(Imports *imports)
         if (!import.object) {
             import.valid = true;
             import.info = info;
-            import.object = new ObjectValue(valueOwner);
+            import.object = new ObjectValue(valueOwner, QLatin1String("<defaults>"));
             foreach (const CppComponentValue *object,
                      valueOwner->cppQmlTypes().createObjectsForImport(
                          defaultPackage, maxVersion)) {
