@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -37,6 +38,7 @@
 #include <coreplugin/dialogs/readonlyfilesdialog.h>
 #include <coreplugin/dialogs/saveitemsdialog.h>
 #include <coreplugin/editormanager/editormanager.h>
+#include <coreplugin/editormanager/editorview.h>
 #include <coreplugin/editormanager/ieditor.h>
 #include <coreplugin/editormanager/ieditorfactory.h>
 #include <coreplugin/editormanager/iexternaleditor.h>
@@ -476,7 +478,7 @@ QString DocumentManager::fixFileName(const QString &fileName, FixMode fixmode)
         s = QDir::cleanPath(s);
     }
     s = QDir::toNativeSeparators(s);
-    if (Utils::HostOsInfo::isWindowsHost())
+    if (Utils::HostOsInfo::fileNameCaseSensitivity() == Qt::CaseInsensitive)
         s = s.toLower();
     return s;
 }
@@ -691,7 +693,7 @@ QString DocumentManager::getSaveFileName(const QString &title, const QString &pa
             }
             if (QFile::exists(fileName)) {
                 if (QMessageBox::warning(ICore::dialogParent(), tr("Overwrite?"),
-                    tr("An item named '%1' already exists at this location. "
+                    tr("An item named \"%1\" already exists at this location. "
                        "Do you want to overwrite it?").arg(fileName),
                     QMessageBox::Yes | QMessageBox::No) == QMessageBox::No) {
                     repeat = true;
@@ -865,8 +867,8 @@ bool DocumentManager::saveModifiedDocument(IDocument *document, const QString &m
 */
 
 QStringList DocumentManager::getOpenFileNames(const QString &filters,
-                                          const QString pathIn,
-                                          QString *selectedFilter)
+                                              const QString &pathIn,
+                                              QString *selectedFilter)
 {
     QString path = pathIn;
     if (path.isEmpty()) {
@@ -1133,7 +1135,7 @@ void DocumentManager::checkForReload()
     \a editorId defaults to the empty id, which lets \QC figure out
     the best editor itself.
 */
-void DocumentManager::addToRecentFiles(const QString &fileName, const Id &editorId)
+void DocumentManager::addToRecentFiles(const QString &fileName, Id editorId)
 {
     if (fileName.isEmpty())
         return;
@@ -1414,19 +1416,42 @@ void DocumentManager::executeOpenWithMenuAction(QAction *action)
     const QVariant data = action->data();
     OpenWithEntry entry = qvariant_cast<OpenWithEntry>(data);
     if (entry.editorFactory) {
-        // close any open editors that have this file open, but have a different type.
+        // close any open editors that have this file open
+        // remember the views to open new editors in there
+        QList<Internal::EditorView *> views;
         QList<IEditor *> editorsOpenForFile
-                = EditorManager::documentModel()->editorsForFilePath(entry.fileName);
-        if (!editorsOpenForFile.isEmpty()) {
-            foreach (IEditor *openEditor, editorsOpenForFile) {
-                if (entry.editorFactory->id() == openEditor->id())
-                    editorsOpenForFile.removeAll(openEditor);
-            }
-            if (!EditorManager::closeEditors(editorsOpenForFile)) // don't open if cancel was pressed
-                return;
+                = DocumentModel::editorsForFilePath(entry.fileName);
+        foreach (IEditor *openEditor, editorsOpenForFile) {
+            Internal::EditorView *view = EditorManager::viewForEditor(openEditor);
+            if (view && view->currentEditor() == openEditor) // visible
+                views.append(view);
         }
+        if (!EditorManager::closeEditors(editorsOpenForFile)) // don't open if cancel was pressed
+            return;
 
-        EditorManager::openEditor(entry.fileName, entry.editorFactory->id());
+        if (views.isEmpty()) {
+            EditorManager::openEditor(entry.fileName, entry.editorFactory->id());
+        } else {
+            if (Internal::EditorView *currentView = EditorManager::currentEditorView()) {
+                if (views.removeOne(currentView))
+                    views.prepend(currentView); // open editor in current view first
+            }
+            EditorManager::OpenEditorFlags flags;
+            foreach (Internal::EditorView *view, views) {
+                IEditor *editor =
+                        EditorManager::openEditor(view, entry.fileName, entry.editorFactory->id(),
+                                                  flags);
+                // Do not change the current editor after opening the first one. That
+                // * prevents multiple updates of focus etc which are not necessary
+                // * lets us control which editor is made current by putting the current editor view
+                //   to the front (if that was in the list in the first place
+                flags |= EditorManager::DoNotChangeCurrentEditor;
+                // do not try to open more editors if this one failed, or editor type does not
+                // support duplication anyhow
+                if (!editor || !editor->duplicateSupported())
+                    break;
+            }
+        }
         return;
     }
     if (entry.externalEditor)
