@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -54,6 +55,8 @@
 #include <QTimer>
 #include <QVariant>
 
+#include <math.h>
+
 static const char kSettingsGroup[] = "Progress";
 static const char kDetailsPinned[] = "DetailsPinned";
 
@@ -129,7 +132,7 @@ using namespace Core::Internal;
     \c QFuture object. This is what you want to give the
     ProgressManager in the addTask() function.
 
-    Have a look at e.g Locator::ILocatorFilter. Locator filters implement
+    Have a look at e.g Core::ILocatorFilter. Locator filters implement
     a function \c refresh which takes a \c QFutureInterface object
     as a parameter. These functions look something like:
     \code
@@ -262,6 +265,8 @@ using namespace Core::Internal;
     Sent when all tasks of a \a type have finished.
 */
 
+static ProgressManagerPrivate *m_instance = 0;
+
 ProgressManagerPrivate::ProgressManagerPrivate()
   : m_applicationTask(0),
     m_currentStatusDetailsWidget(0),
@@ -269,6 +274,7 @@ ProgressManagerPrivate::ProgressManagerPrivate()
     m_progressViewPinned(false),
     m_hovered(false)
 {
+    m_instance = this;
     m_progressView = new ProgressView;
     // withDelay, so the statusBarWidget has the chance to get the enter event
     connect(m_progressView, SIGNAL(hoveredChanged(bool)), this, SLOT(updateVisibilityWithDelay()));
@@ -282,6 +288,7 @@ ProgressManagerPrivate::~ProgressManagerPrivate()
     ExtensionSystem::PluginManager::removeObject(m_statusBarWidgetContainer);
     delete m_statusBarWidgetContainer;
     cleanup();
+    m_instance = 0;
 }
 
 void ProgressManagerPrivate::readSettings()
@@ -715,16 +722,12 @@ void ToggleButton::paintEvent(QPaintEvent *event)
 }
 
 
-static ProgressManager *m_instance = 0;
-
 ProgressManager::ProgressManager()
 {
-    m_instance = this;
 }
 
 ProgressManager::~ProgressManager()
 {
-    m_instance = 0;
 }
 
 QObject *ProgressManager::instance()
@@ -737,13 +740,64 @@ FutureProgress *ProgressManager::addTask(const QFuture<void> &future, const QStr
     return m_instance->doAddTask(future, title, type, flags);
 }
 
+/*!
+    Shows a progress indicator for task given by the QFuture given by
+    the QFutureInterface \a futureInterface.
+    The progress indicator shows the specified \a title along with the progress bar.
+    The progress indicator will increase monotonically with time, at \a expectedSeconds
+    it will reach about 80%, and continue to increase with a decreasingly slower rate.
+
+    \sa addTask
+*/
+
+FutureProgress *ProgressManager::addTimedTask(const QFutureInterface<void> &futureInterface, const QString &title,
+                                              Id type, int expectedSeconds, ProgressFlags flags)
+{
+    QFutureInterface<void> dummy(futureInterface); // Need mutable to access .future()
+    FutureProgress *fp = m_instance->doAddTask(dummy.future(), title, type, flags);
+    (void) new ProgressTimer(fp, futureInterface, expectedSeconds);
+    return fp;
+}
+
 void ProgressManager::setApplicationLabel(const QString &text)
 {
     m_instance->doSetApplicationLabel(text);
 }
 
-void ProgressManager::cancelTasks(const Id type)
+void ProgressManager::cancelTasks(Id type)
 {
     if (m_instance)
         m_instance->doCancelTasks(type);
 }
+
+
+ProgressTimer::ProgressTimer(QObject *parent,
+                             const QFutureInterface<void> &futureInterface,
+                             int expectedSeconds)
+    : QTimer(parent),
+      m_futureInterface(futureInterface),
+      m_expectedTime(expectedSeconds),
+      m_currentTime(0)
+{
+    m_futureWatcher.setFuture(m_futureInterface.future());
+
+    m_futureInterface.setProgressRange(0, 100);
+    m_futureInterface.setProgressValue(0);
+
+    setInterval(1000); // 1 second
+    connect(this, SIGNAL(timeout()), this, SLOT(handleTimeout()));
+    connect(&m_futureWatcher, SIGNAL(started()), this, SLOT(start()));
+}
+
+void ProgressTimer::handleTimeout()
+{
+    ++m_currentTime;
+
+    // This maps expectation to atan(1) to Pi/4 ~= 0.78, i.e. snaps
+    // from 78% to 100% when expectations are met at the time the
+    // future finishes. That's not bad for a random choice.
+    const double mapped = atan2(double(m_currentTime), double(m_expectedTime));
+    const double progress = 100 * 2 * mapped / 3.14;
+    m_futureInterface.setProgressValue(int(progress));
+}
+
