@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -29,6 +30,8 @@
 
 #include "cppelementevaluator.h"
 
+#include "cppeditor.h"
+
 #include <cpptools/cpptoolsreuse.h>
 #include <cpptools/typehierarchybuilder.h>
 
@@ -59,7 +62,7 @@ namespace {
     }
 }
 
-CppElementEvaluator::CppElementEvaluator(CPPEditorWidget *editor) :
+CppElementEvaluator::CppElementEvaluator(TextEditor::BaseTextEditorWidget *editor) :
     m_editor(editor),
     m_modelManager(CppTools::CppModelManagerInterface::instance()),
     m_tc(editor->textCursor()),
@@ -142,9 +145,9 @@ bool CppElementEvaluator::matchIncludeFile(const CPlusPlus::Document::Ptr &docum
 bool CppElementEvaluator::matchMacroInUse(const CPlusPlus::Document::Ptr &document, unsigned pos)
 {
     foreach (const Document::MacroUse &use, document->macroUses()) {
-        if (use.contains(pos)) {
-            const unsigned begin = use.begin();
-            if (pos < begin + use.macro().name().length()) {
+        if (use.containsUtf16charOffset(pos)) {
+            const unsigned begin = use.utf16charsBegin();
+            if (pos < begin + use.macro().nameToQString().size()) {
                 m_element = QSharedPointer<CppElement>(new CppMacro(use.macro()));
                 return true;
             }
@@ -163,7 +166,7 @@ void CppElementEvaluator::handleLookupItemMatch(const Snapshot &snapshot,
         const QString &type = Overview().prettyType(lookupItem.type(), QString());
         //  special case for bug QTCREATORBUG-4780
         if (scope && scope->isFunction()
-                && lookupItem.type().isEqualTo(scope->asFunction()->returnType())) {
+                && lookupItem.type().match(scope->asFunction()->returnType())) {
             return;
         }
         m_element = QSharedPointer<CppElement>(new Unknown(type));
@@ -262,7 +265,7 @@ CppInclude::CppInclude(const Document::Include &includeFile) :
     helpCategory = TextEditor::HelpItem::Brief;
     helpIdCandidates = QStringList(fileName);
     helpMark = fileName;
-    link = CPPEditorWidget::Link(path);
+    link = TextEditor::BaseTextEditorWidget::Link(path);
     tooltip = path;
 }
 
@@ -270,10 +273,10 @@ CppInclude::CppInclude(const Document::Include &includeFile) :
 CppMacro::CppMacro(const Macro &macro)
 {
     helpCategory = TextEditor::HelpItem::Macro;
-    const QString macroName = QLatin1String(macro.name());
+    const QString macroName = QString::fromUtf8(macro.name(), macro.name().size());
     helpIdCandidates = QStringList(macroName);
     helpMark = macroName;
-    link = CPPEditorWidget::Link(macro.fileName(), macro.line());
+    link = TextEditor::BaseTextEditorWidget::Link(macro.fileName(), macro.line());
     tooltip = macro.toStringWithLineBreaks();
 }
 
