@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -87,6 +88,8 @@ public:
         // Get Document
         waitForFileInGlobalSnapshot(fileName);
         const Document::Ptr document = globalSnapshot().document(fileName);
+        QVERIFY(document);
+        QVERIFY(document->diagnosticMessages().isEmpty());
 
         m_snapshot.insert(document);
 
@@ -103,7 +106,7 @@ public:
             = new CppCompletionAssistInterface(m_editorWidget->document(), m_position,
                                                m_editorWidget->baseTextDocument()->filePath(),
                                                ExplicitlyInvoked, m_snapshot,
-                                               QStringList(), QStringList());
+                                               ProjectPart::HeaderPaths());
         CppCompletionAssistProcessor processor;
         IAssistProposal *proposal = processor.perform(ai);
         if (!proposal)
@@ -346,7 +349,7 @@ void CppToolsPlugin::test_completion_data()
             "{\n"
             "    Base *b = new Derived;\n"
             "    if (1)\n"
-            "        @\n"
+            "        @;\n"
             "}\n"
         ) << _("((Derived *)b)->") << (QStringList()
             << QLatin1String("Derived")
@@ -369,7 +372,7 @@ void CppToolsPlugin::test_completion_data()
             "{\n"
             "    Base *b = new Derived;\n"
             "    if (1)\n"
-            "        @\n"
+            "        @;\n"
             "}\n"
         ) << _("(static_cast<Derived *>(b))->") << (QStringList()
             << QLatin1String("Derived")
@@ -1524,7 +1527,7 @@ void CppToolsPlugin::test_completion_data()
             "       int foo2;\n"
             "   };\n"
             "   @\n"
-            "};\n"
+            "}\n"
         ) << _("foo") << (QStringList()
             << QLatin1String("foo1")
             << QLatin1String("foo2"));
@@ -1706,6 +1709,7 @@ void CppToolsPlugin::test_completion_data()
             "        int m;\n"
             "    };\n"
             "}\n"
+            "}\n"
             "void foo()\n"
             "{\n"
             "   namespace NS = NS1::NS2;\n"
@@ -1727,6 +1731,7 @@ void CppToolsPlugin::test_completion_data()
             "        int m;\n"
             "    };\n"
             "}\n"
+            "}\n"
             "void foo()\n"
             "{\n"
             "   {\n"
@@ -1825,7 +1830,6 @@ void CppToolsPlugin::test_completion_data()
             "   enum E { val1, val2, val3 };\n"
             "   @\n"
             "};\n"
-            "@\n"
         ) << _("Foo::v") << (QStringList()
             << QLatin1String("val1")
             << QLatin1String("val2")
@@ -1837,7 +1841,6 @@ void CppToolsPlugin::test_completion_data()
             "   enum E { val1, val2, val3 };\n"
             "   @\n"
             "};\n"
-            "@\n"
         ) << _("Foo::E::") << (QStringList()
             << QLatin1String("E")
             << QLatin1String("val1")
@@ -1850,7 +1853,6 @@ void CppToolsPlugin::test_completion_data()
             "   enum { val1, val2, val3 };\n"
             "   @\n"
             "};\n"
-            "@\n"
         ) << _("Foo::v") << (QStringList()
             << QLatin1String("val1")
             << QLatin1String("val2")
@@ -1875,8 +1877,7 @@ void CppToolsPlugin::test_completion_data()
             "{\n"
             "   enum E { val1, val2, val3 };\n"
             "   @\n"
-            "};\n"
-            "@\n"
+            "}\n"
         ) << _("Ns::v") << (QStringList()
             << QLatin1String("val1")
             << QLatin1String("val2")
@@ -1887,8 +1888,7 @@ void CppToolsPlugin::test_completion_data()
             "{\n"
             "   enum E { val1, val2, val3 };\n"
             "   @\n"
-            "};\n"
-            "@\n"
+            "}\n"
         ) << _("Ns::E::") << (QStringList()
             << QLatin1String("E")
             << QLatin1String("val1")
@@ -1900,8 +1900,7 @@ void CppToolsPlugin::test_completion_data()
             "{\n"
             "   enum { val1, val2, val3 };\n"
             "   @\n"
-            "};\n"
-            "@\n"
+            "}\n"
         ) << _("Ns::v") << (QStringList()
             << QLatin1String("val1")
             << QLatin1String("val2")
@@ -2202,9 +2201,9 @@ void CppToolsPlugin::test_completion_data()
             "void client()\n"
             "{\n"
             "    Timer *timer = new Timer;\n"
-            "    connect(timer, SIGNAL(@\n"
+            "    @\n"
             "}\n"
-        ) << _() << (QStringList()
+        ) << _("connect(timer, SIGNAL(") << (QStringList()
             << QLatin1String("timeout()"));
 
     QTest::newRow("member_of_class_accessed_by_using_QTCREATORBUG9037_1") << _(
@@ -2246,9 +2245,9 @@ void CppToolsPlugin::test_completion_data()
             "\n"
             "double getValue(const QVector<V>& d) const {\n"
             "   typedef QVector<V>::ConstIterator Iter;\n"
-            "   double val = @\n"
+            "   @\n"
             "}\n"
-        ) << _("d.constBegin()->") << (QStringList());
+        ) << _("double val = d.constBegin()->") << (QStringList());
 
     QTest::newRow("nested_class_in_template_class_QTCREATORBUG-11752") << _(
             "template <typename T>\n"
@@ -2265,6 +2264,38 @@ void CppToolsPlugin::test_completion_data()
         ) << _("n2.n1.t.") << (QStringList()
             << QLatin1String("foo")
             << QLatin1String("Foo"));
+
+    QTest::newRow("lambda_parameter") << _(
+            "auto func = [](int arg1) { return @; };\n"
+        ) << _("ar") << (QStringList()
+            << QLatin1String("arg1"));
+
+    QTest::newRow("default_arguments_for_class_templates_and_base_class_QTCREATORBUG-12605") << _(
+            "struct Foo { int foo; };\n"
+            "template <typename T = Foo>\n"
+            "struct Derived : T {};\n"
+            "void fun() {\n"
+            "   Derived<> derived;\n"
+            "   @\n"
+            "}\n"
+        ) << _("derived.") << (QStringList()
+            << QLatin1String("Derived")
+            << QLatin1String("foo")
+            << QLatin1String("Foo"));
+
+    QTest::newRow("default_arguments_for_class_templates_and_template_base_class_QTCREATORBUG-12606") << _(
+            "struct Foo { int foo; };\n"
+            "template <typename T>\n"
+            "struct Base { T t; };\n"
+            "template <typename T = Foo>\n"
+            "struct Derived : Base<T> {};\n"
+            "void fun() {\n"
+            "   Derived<> derived;\n"
+            "   @\n"
+            "}\n"
+        ) << _("derived.t.") << (QStringList()
+            << QLatin1String("foo")
+            << QLatin1String("Foo"));
 }
 
 void CppToolsPlugin::test_completion_member_access_operator()
@@ -2309,7 +2340,6 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "typedef S SType;\n"
             "SType p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList()
             << QLatin1String("S")
             << QLatin1String("m"))
@@ -2320,7 +2350,6 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "typedef S *SType;\n"
             "SType *p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList())
         << false;
 
@@ -2329,7 +2358,6 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "typedef S SType;\n"
             "SType *p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList()
             << QLatin1String("S")
             << QLatin1String("m"))
@@ -2340,7 +2368,6 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "typedef S* SPtr;\n"
             "SPtr p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList()
             << QLatin1String("S")
             << QLatin1String("m"))
@@ -2351,7 +2378,6 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "struct S { int m; };\n"
             "SType *p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList()
             << QLatin1String("S")
             << QLatin1String("m"))
@@ -2362,7 +2388,6 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "struct S { int m; };\n"
             "SType p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList()
             << QLatin1String("S")
             << QLatin1String("m"))
@@ -2373,7 +2398,6 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "struct S { int m; };\n"
             "SType *p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList())
         << false;
 
@@ -2382,9 +2406,30 @@ void CppToolsPlugin::test_completion_member_access_operator_data()
             "struct S { int m; };\n"
             "SType p;\n"
             "@\n"
-            "}\n"
         ) << _("p.") << (QStringList()
             << QLatin1String("S")
             << QLatin1String("m"))
         << true;
+
+    QTest::newRow("typedef_of_pointer_of_type_replace_access_operator") << _(
+            "struct S { int m; };\n"
+            "typedef struct S SType;\n"
+            "typedef struct SType *STypePtr;\n"
+            "STypePtr p;\n"
+            "@\n"
+        ) << _("p.") << (QStringList()
+            << QLatin1String("S")
+            << QLatin1String("m"))
+        << true;
+
+    QTest::newRow("typedef_of_pointer_of_type_no_replace_access_operator") << _(
+            "struct S { int m; };\n"
+            "typedef struct S SType;\n"
+            "typedef struct SType *STypePtr;\n"
+            "STypePtr p;\n"
+            "@\n"
+        ) << _("p->") << (QStringList()
+            << QLatin1String("S")
+            << QLatin1String("m"))
+        << false;
 }
