@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -114,7 +115,7 @@ namespace Internal {
 
 const char INSTALL_HANDLER[]                = "TextEditor.FakeVimHandler";
 const char SETTINGS_CATEGORY[]              = "D.FakeVim";
-const char SETTINGS_CATEGORY_FAKEVIM_ICON[] = ":/core/images/category_fakevim.png";
+const char SETTINGS_CATEGORY_FAKEVIM_ICON[] = ":/fakevim/images/category_fakevim.png";
 const char SETTINGS_ID[]                    = "A.General";
 const char SETTINGS_EX_CMDS_ID[]            = "B.ExCommands";
 const char SETTINGS_USER_CMDS_ID[]          = "C.UserCommands";
@@ -831,7 +832,7 @@ void FakeVimUserCommandsPage::apply()
 class FakeVimCompletionAssistProvider : public CompletionAssistProvider
 {
 public:
-    bool supportsEditor(const Id &) const
+    bool supportsEditor(Id ) const
     {
         return false;
     }
@@ -1018,7 +1019,9 @@ private slots:
     void jumpToGlobalMark(QChar mark, bool backTickMode, const QString &fileName);
     void showSettingsDialog();
     void maybeReadVimRc();
-    void setBlockSelection(bool);
+    void disableBlockSelection();
+    void setBlockSelection(const QTextCursor&);
+    void blockSelection(QTextCursor *);
     void hasBlockSelection(bool*);
     void setShowRelativeLineNumbers(const QVariant &value);
 
@@ -1056,8 +1059,8 @@ private:
     FakeVimUserCommandsPage *m_fakeVimUserCommandsPage;
     QHash<IEditor *, FakeVimHandler *> m_editorToHandler;
 
-    void triggerAction(const Id &id);
-    void setActionChecked(const Id &id, bool check);
+    void triggerAction(Id id);
+    void setActionChecked(Id id, bool check);
 
     typedef int (*DistFunction)(const QRect &cursor, const QRect &other);
     void moveSomewhere(DistFunction f, int count);
@@ -1384,7 +1387,7 @@ void FakeVimPluginPrivate::showSettingsDialog()
     ICore::showOptionsDialog(SETTINGS_CATEGORY, SETTINGS_ID);
 }
 
-void FakeVimPluginPrivate::triggerAction(const Id &id)
+void FakeVimPluginPrivate::triggerAction(Id id)
 {
     Core::Command *cmd = ActionManager::command(id);
     QTC_ASSERT(cmd, qDebug() << "UNKNOWN CODE: " << id.name(); return);
@@ -1393,7 +1396,7 @@ void FakeVimPluginPrivate::triggerAction(const Id &id)
     action->trigger();
 }
 
-void FakeVimPluginPrivate::setActionChecked(const Id &id, bool check)
+void FakeVimPluginPrivate::setActionChecked(Id id, bool check)
 {
     Core::Command *cmd = ActionManager::command(id);
     QTC_ASSERT(cmd, return);
@@ -1762,15 +1765,19 @@ void FakeVimPluginPrivate::editorOpened(IEditor *editor)
     connect(handler, SIGNAL(highlightMatches(QString)),
         SLOT(highlightMatches(QString)));
     connect(handler, SIGNAL(moveToMatchingParenthesis(bool*,bool*,QTextCursor*)),
-        SLOT(moveToMatchingParenthesis(bool*,bool*,QTextCursor*)));
+        SLOT(moveToMatchingParenthesis(bool*,bool*,QTextCursor*)), Qt::DirectConnection);
     connect(handler, SIGNAL(indentRegion(int,int,QChar)),
         SLOT(indentRegion(int,int,QChar)));
     connect(handler, SIGNAL(checkForElectricCharacter(bool*,QChar)),
-        SLOT(checkForElectricCharacter(bool*,QChar)));
-    connect(handler, SIGNAL(requestSetBlockSelection(bool)),
-        SLOT(setBlockSelection(bool)));
+        SLOT(checkForElectricCharacter(bool*,QChar)), Qt::DirectConnection);
+    connect(handler, SIGNAL(requestDisableBlockSelection()),
+        SLOT(disableBlockSelection()));
+    connect(handler, SIGNAL(requestSetBlockSelection(QTextCursor)),
+        SLOT(setBlockSelection(QTextCursor)));
+    connect(handler, SIGNAL(requestBlockSelection(QTextCursor*)),
+        SLOT(blockSelection(QTextCursor*)), Qt::DirectConnection);
     connect(handler, SIGNAL(requestHasBlockSelection(bool*)),
-        SLOT(hasBlockSelection(bool*)));
+        SLOT(hasBlockSelection(bool*)), Qt::DirectConnection);
     connect(handler, SIGNAL(completionRequested()),
         SLOT(triggerCompletions()));
     connect(handler, SIGNAL(simpleCompletionRequested(QString,bool)),
@@ -1793,7 +1800,7 @@ void FakeVimPluginPrivate::editorOpened(IEditor *editor)
         SLOT(jumpToGlobalMark(QChar,bool,QString)));
 
     connect(handler, SIGNAL(handleExCommandRequested(bool*,ExCommand)),
-        SLOT(handleExCommand(bool*,ExCommand)));
+        SLOT(handleExCommand(bool*,ExCommand)), Qt::DirectConnection);
 
     connect(ICore::instance(), SIGNAL(saveSettingsRequested()),
         SLOT(writeSettings()));
@@ -1864,13 +1871,32 @@ void FakeVimPluginPrivate::triggerSimpleCompletions(const QString &needle, bool
     m_wordProvider->setActive(needle, forward, qobject_cast<FakeVimHandler *>(sender()));
 }
 
-void FakeVimPluginPrivate::setBlockSelection(bool on)
+void FakeVimPluginPrivate::disableBlockSelection()
 {
     FakeVimHandler *handler = qobject_cast<FakeVimHandler *>(sender());
     if (!handler)
         return;
     if (BaseTextEditorWidget *bt = qobject_cast<BaseTextEditorWidget *>(handler->widget()))
-        bt->setBlockSelection(on);
+        bt->setBlockSelection(false);
+}
+
+void FakeVimPluginPrivate::setBlockSelection(const QTextCursor &cursor)
+{
+    FakeVimHandler *handler = qobject_cast<FakeVimHandler *>(sender());
+    if (!handler)
+        return;
+    if (BaseTextEditorWidget *bt = qobject_cast<BaseTextEditorWidget *>(handler->widget()))
+        bt->setBlockSelection(cursor);
+}
+
+void FakeVimPluginPrivate::blockSelection(QTextCursor *cursor)
+{
+    FakeVimHandler *handler = qobject_cast<FakeVimHandler *>(sender());
+    if (!handler)
+        return;
+    if (BaseTextEditorWidget *bt = qobject_cast<BaseTextEditorWidget *>(handler->widget()))
+        if (cursor)
+            *cursor = bt->blockSelection();
 }
 
 void FakeVimPluginPrivate::hasBlockSelection(bool *on)
@@ -2149,17 +2175,17 @@ int FakeVimPluginPrivate::currentFile() const
     IEditor *editor = EditorManager::currentEditor();
     if (!editor)
         return -1;
-    return EditorManager::documentModel()->indexOfDocument(editor->document());
+    return DocumentModel::indexOfDocument(editor->document());
 }
 
 void FakeVimPluginPrivate::switchToFile(int n)
 {
-    int size = EditorManager::documentModel()->documentCount();
+    int size = DocumentModel::entryCount();
     QTC_ASSERT(size, return);
     n = n % size;
     if (n < 0)
         n += size;
-    EditorManager::activateEditorForEntry(EditorManager::documentModel()->documents().at(n));
+    EditorManager::activateEditorForEntry(DocumentModel::entries().at(n));
 }
 
 ExCommandMap &FakeVimExCommandsPage::exCommandMap()
