@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -719,7 +720,6 @@ void PerforcePlugin::annotate(const QString &workingDir,
     if (!result.error) {
         if (lineNumber < 1)
             lineNumber = VcsBase::VcsBaseEditorWidget::lineNumberOfCurrentEditor();
-        const QFileInfo fi(fileName);
         Core::IEditor *ed = showOutputInEditor(tr("p4 annotate %1").arg(id),
                                                result.stdOut, VcsBase::AnnotateOutput,
                                                source, codec);
@@ -782,13 +782,37 @@ void PerforcePlugin::filelog(const QString &workingDir, const QString &fileName,
 
 void PerforcePlugin::updateActions(VcsBase::VcsBasePlugin::ActionState as)
 {
-    if (!enableMenuAction(as, m_menuAction)) {
-        m_commandLocator->setEnabled(false);
+    const bool menuActionEnabled = enableMenuAction(as, m_menuAction);
+    const bool enableActions = currentState().hasTopLevel() && menuActionEnabled;
+    m_commandLocator->setEnabled(enableActions);
+    m_logRepositoryAction->setEnabled(enableActions);
+    m_editAction->setEnabled(enableActions);
+    m_addAction->setEnabled(enableActions);
+    m_deleteAction->setEnabled(enableActions);
+    m_openedAction->setEnabled(enableActions);
+    m_revertFileAction->setEnabled(enableActions);
+    m_diffFileAction->setEnabled(enableActions);
+    m_diffProjectAction->setEnabled(enableActions);
+    m_updateProjectAction->setEnabled(enableActions);
+    m_revertProjectAction->setEnabled(enableActions);
+    m_revertUnchangedAction->setEnabled(enableActions);
+    m_diffAllAction->setEnabled(enableActions);
+    m_submitProjectAction->setEnabled(enableActions);
+    m_pendingAction->setEnabled(enableActions);
+    m_describeAction->setEnabled(enableActions);
+    m_annotateCurrentAction->setEnabled(enableActions);
+    m_annotateAction->setEnabled(enableActions);
+    m_filelogCurrentAction->setEnabled(enableActions);
+    m_filelogAction->setEnabled(enableActions);
+    m_logProjectAction->setEnabled(enableActions);
+    m_logRepositoryAction->setEnabled(enableActions);
+    m_submitCurrentLogAction->setEnabled(enableActions);
+    m_updateAllAction->setEnabled(enableActions);
+    m_diffSelectedFiles->setEnabled(enableActions);
+    m_undoAction->setEnabled(enableActions);
+    m_redoAction->setEnabled(enableActions);
+    if (!menuActionEnabled)
         return;
-    }
-    const bool hasTopLevel = currentState().hasTopLevel();
-    m_commandLocator->setEnabled(hasTopLevel);
-    m_logRepositoryAction->setEnabled(hasTopLevel);
 
     const QString fileName = currentState().currentFileName();
     m_editAction->setParameter(fileName);
@@ -806,14 +830,6 @@ void PerforcePlugin::updateActions(VcsBase::VcsBasePlugin::ActionState as)
     m_submitProjectAction->setParameter(projectName);
     m_revertProjectAction->setParameter(projectName);
     m_revertUnchangedAction->setParameter(projectName);
-
-    m_diffAllAction->setEnabled(true);
-    m_openedAction->setEnabled(true);
-    m_describeAction->setEnabled(true);
-    m_annotateAction->setEnabled(true);
-    m_filelogAction->setEnabled(true);
-    m_pendingAction->setEnabled(true);
-    m_updateAllAction->setEnabled(true);
 }
 
 bool PerforcePlugin::managesDirectory(const QString &directory, QString *topLevel /* = 0 */)
@@ -960,7 +976,7 @@ PerforcePlugin::createTemporaryArgumentFile(const QStringList &extraArgs,
 
 static inline QString msgNotStarted(const QString &cmd)
 {
-    return PerforcePlugin::tr("Could not start perforce '%1'. Please check your settings in the preferences.").arg(cmd);
+    return PerforcePlugin::tr("Could not start perforce \"%1\". Please check your settings in the preferences.").arg(cmd);
 }
 
 static inline QString msgTimeout(int timeOut)
@@ -1170,10 +1186,11 @@ PerforceResponse PerforcePlugin::runP4Cmd(const QString &workingDir,
     return response;
 }
 
-Core::IEditor *PerforcePlugin::showOutputInEditor(const QString &title, const QString output,
-                                                   int editorType,
-                                                   const QString &source,
-                                                   QTextCodec *codec)
+Core::IEditor *PerforcePlugin::showOutputInEditor(const QString &title,
+                                                  const QString &output,
+                                                  int editorType,
+                                                  const QString &source,
+                                                  QTextCodec *codec)
 {
     const VcsBase::VcsBaseEditorParameters *params = findType(editorType);
     QTC_ASSERT(params, return 0);
@@ -1182,10 +1199,7 @@ Core::IEditor *PerforcePlugin::showOutputInEditor(const QString &title, const QS
         qDebug() << "PerforcePlugin::showOutputInEditor" << title << id.name()
                  <<  "Size= " << output.size() <<  " Type=" << editorType << debugCodec(codec);
     QString s = title;
-    Core::IEditor *editor
-            = Core::EditorManager::openEditorWithContents(id, &s, output.toUtf8(),
-                                                          (Core::EditorManager::OpenInOtherSplit
-                                                           | Core::EditorManager::NoNewSplits));
+    Core::IEditor *editor = Core::EditorManager::openEditorWithContents(id, &s, output.toUtf8());
     connect(editor, SIGNAL(annotateRevisionRequested(QString,QString,QString,int)),
             this, SLOT(vcsAnnotate(QString,QString,QString,int)));
     PerforceEditor *e = qobject_cast<PerforceEditor*>(editor->widget());
