@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -34,14 +35,16 @@
 #include "projectexplorer.h"
 
 #include <coreplugin/fileiconprovider.h>
+#include <utils/algorithm.h>
 
 #include <QDebug>
 #include <QFileInfo>
 
 #include <QFont>
 
-using namespace ProjectExplorer;
-using namespace ProjectExplorer::Internal;
+namespace ProjectExplorer {
+
+using namespace Internal;
 
 namespace {
 
@@ -135,13 +138,17 @@ bool sortNodes(Node *n1, Node *n2)
 
     // must be file nodes
     {
+        int result = caseFriendlyCompare(n1->displayName(), n2->displayName());
+        if (result != 0)
+            return result < 0;
+
         const QString filePath1 = n1->path();
         const QString filePath2 = n2->path();
 
         const QString fileName1 = QFileInfo(filePath1).fileName();
         const QString fileName2 = QFileInfo(filePath2).fileName();
 
-        int result = caseFriendlyCompare(fileName1, fileName2);
+        result = caseFriendlyCompare(fileName1, fileName2);
         if (result != 0) {
             return result < 0; // sort by filename
         } else {
@@ -170,11 +177,11 @@ FlatModel::FlatModel(SessionNode *rootNode, QObject *parent)
     NodesWatcher *watcher = new NodesWatcher(this);
     m_rootNode->registerWatcher(watcher);
 
-    connect(watcher, SIGNAL(aboutToChangeHasBuildTargets(ProjectExplorer::ProjectNode*)),
-            this, SLOT(aboutToHasBuildTargetsChanged(ProjectExplorer::ProjectNode*)));
+    connect(watcher, SIGNAL(aboutToChangeShowInSimpleTree(ProjectExplorer::FolderNode*)),
+            this, SLOT(aboutToShowInSimpleTreeChanged(ProjectExplorer::FolderNode*)));
 
-    connect(watcher, SIGNAL(hasBuildTargetsChanged(ProjectExplorer::ProjectNode*)),
-            this, SLOT(hasBuildTargetsChanged(ProjectExplorer::ProjectNode*)));
+    connect(watcher, SIGNAL(showInSimpleTreeChanged(ProjectExplorer::FolderNode*)),
+            this, SLOT(showInSimpleTreeChanged(ProjectExplorer::FolderNode*)));
 
     connect(watcher, SIGNAL(foldersAboutToBeAdded(FolderNode*,QList<FolderNode*>)),
             this, SLOT(foldersAboutToBeAdded(FolderNode*,QList<FolderNode*>)));
@@ -265,9 +272,10 @@ QVariant FlatModel::data(const QModelIndex &index, int role) const
         case Qt::DisplayRole: {
             QString name = node->displayName();
 
-            if (node->parentFolderNode()
+            if (node->nodeType() == ProjectNodeType
+                    && node->parentFolderNode()
                     && node->parentFolderNode()->nodeType() == SessionNodeType) {
-                const QString vcsTopic = node->vcsTopic();
+                const QString vcsTopic = static_cast<ProjectNode *>(node)->vcsTopic();
 
                 if (!vcsTopic.isEmpty())
                     name += QLatin1String(" [") + vcsTopic + QLatin1Char(']');
@@ -277,7 +285,7 @@ QVariant FlatModel::data(const QModelIndex &index, int role) const
             break;
         }
         case Qt::EditRole: {
-            result = node->displayName();
+            result = QFileInfo(node->path()).fileName();
             break;
         }
         case Qt::ToolTipRole: {
@@ -325,7 +333,7 @@ Qt::ItemFlags FlatModel::flags(const QModelIndex &index) const
             return 0; // no flags for session node...
         if (!qobject_cast<ProjectNode *>(node)) {
             // either folder or file node
-            if (node->projectNode()->supportedActions(node).contains(ProjectNode::Rename))
+            if (node->supportedActions(node).contains(ProjectExplorer::Rename))
                 f = f | Qt::ItemIsEditable;
         }
     }
@@ -438,7 +446,7 @@ QList<Node*> FlatModel::childNodes(FolderNode *parentNode, const QSet<Node*> &bl
         recursiveAddFolderNodes(parentNode, &nodeList, blackList);
         recursiveAddFileNodes(parentNode, &nodeList, blackList + nodeList.toSet());
     }
-    qSort(nodeList.begin(), nodeList.end(), sortNodes);
+    Utils::sort(nodeList, sortNodes);
     return nodeList;
 }
 
@@ -560,14 +568,9 @@ FolderNode *FlatModel::visibleFolderNode(FolderNode *node) const
 bool FlatModel::filter(Node *node) const
 {
     bool isHidden = false;
-    if (node->nodeType() == SessionNodeType) {
-        isHidden = false;
-    } else if (ProjectNode *projectNode = qobject_cast<ProjectNode*>(node)) {
-        if (m_filterProjects && projectNode->parentFolderNode() != m_rootNode)
-            isHidden = !projectNode->hasBuildTargets();
-    } else if (node->nodeType() == FolderNodeType || node->nodeType() == VirtualFolderNodeType) {
+    if (FolderNode *folderNode = qobject_cast<FolderNode*>(node)) {
         if (m_filterProjects)
-            isHidden = true;
+            isHidden = !folderNode->showInSimpleTree();
     } else if (FileNode *fileNode = qobject_cast<FileNode*>(node)) {
         if (m_filterGeneratedFiles)
             isHidden = fileNode->isGenerated();
@@ -756,7 +759,7 @@ void FlatModel::removed(FolderNode* parentNode, const QList<Node*> &newNodeList)
     }
 }
 
-void FlatModel::aboutToHasBuildTargetsChanged(ProjectExplorer::ProjectNode* node)
+void FlatModel::aboutToShowInSimpleTreeChanged(ProjectExplorer::FolderNode* node)
 {
     if (!m_filterProjects)
         return;
@@ -771,7 +774,7 @@ void FlatModel::aboutToHasBuildTargetsChanged(ProjectExplorer::ProjectNode* node
             m_childNodes.remove(fn);
 }
 
-void FlatModel::hasBuildTargetsChanged(ProjectExplorer::ProjectNode *node)
+void FlatModel::showInSimpleTreeChanged(ProjectExplorer::FolderNode *node)
 {
     if (!m_filterProjects)
         return;
@@ -821,6 +824,9 @@ void FlatModel::removeFromCache(QList<FolderNode *> list)
 
 void FlatModel::changedSortKey(FolderNode *folderNode, Node *node)
 {
+    if (!m_childNodes.contains(folderNode))
+        return; // The directory was not yet mapped, so there is no need to sort it.
+
     QList<Node *> nodes = m_childNodes.value(folderNode);
     int oldIndex = nodes.indexOf(node);
 
@@ -898,7 +904,6 @@ void FlatModel::nodeUpdated(Node *node)
     emit dataChanged(idx, idx);
 }
 
-namespace ProjectExplorer {
 namespace Internal {
 
 int caseFriendlyCompare(const QString &a, const QString &b)
@@ -910,5 +915,6 @@ int caseFriendlyCompare(const QString &a, const QString &b)
 }
 
 }
-}
+
+} // namespace ProjectExplorer
 
