@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -177,7 +178,7 @@ void Target::changeRunConfigurationEnabled()
 void Target::onBuildDirectoryChanged()
 {
     BuildConfiguration *bc = qobject_cast<BuildConfiguration *>(sender());
-    if (bc)
+    if (bc && activeBuildConfiguration() == bc)
         emit buildDirectoryChanged();
 }
 
@@ -238,6 +239,8 @@ void Target::addBuildConfiguration(BuildConfiguration *configuration)
             SLOT(changeEnvironment()));
     connect(configuration, SIGNAL(enabledChanged()),
             this, SLOT(changeBuildConfigurationEnabled()));
+    connect(configuration, SIGNAL(buildDirectoryChanged()),
+            SLOT(onBuildDirectoryChanged()));
 
     if (!activeBuildConfiguration())
         setActiveBuildConfiguration(configuration);
@@ -528,7 +531,7 @@ void Target::updateDefaultBuildConfigurations()
         qWarning("No build configuration factory found for target id '%s'.", qPrintable(id().toString()));
         return;
     }
-    QList<BuildInfo *> infoList = bcFactory->availableSetups(this->kit(), project()->projectFilePath());
+    QList<BuildInfo *> infoList = bcFactory->availableSetups(this->kit(), project()->projectFilePath().toString());
     foreach (BuildInfo *info, infoList) {
         BuildConfiguration *bc = bcFactory->create(this, info);
         if (!bc)
@@ -597,26 +600,31 @@ void Target::updateDefaultRunConfigurations()
     int configuredCount = existingConfigured.count();
 
     // find all RC ids that can get created:
-    QList<Core::Id> factoryIds;
+    QList<Core::Id> availableFactoryIds;
     foreach (IRunConfigurationFactory *rcFactory, rcFactories)
-        factoryIds.append(rcFactory->availableCreationIds(this));
+        availableFactoryIds.append(rcFactory->availableCreationIds(this));
+
+    QList<Core::Id> autoCreateFactoryIds;
+    foreach (IRunConfigurationFactory *rcFactory, rcFactories)
+        autoCreateFactoryIds.append(rcFactory->availableCreationIds(this,
+                                                                    IRunConfigurationFactory::AutoCreate));
 
     // Put outdated RCs into toRemove, do not bother with factories
     // that produce already existing RCs
     QList<RunConfiguration *> toRemove;
     QList<Core::Id> toIgnore;
     foreach (RunConfiguration *rc, existingConfigured) {
-        if (factoryIds.contains(rc->id()))
+        if (availableFactoryIds.contains(rc->id()))
             toIgnore.append(rc->id()); // Already there
         else
             toRemove << rc;
     }
     foreach (Core::Id i, toIgnore)
-        factoryIds.removeAll(i);
+        autoCreateFactoryIds.removeAll(i);
     configuredCount -= toRemove.count();
 
     // Create new RCs and put them into newConfigured/newUnconfigured
-    foreach (Core::Id id, factoryIds) {
+    foreach (Core::Id id, autoCreateFactoryIds) {
         IRunConfigurationFactory *factory = 0;
         foreach (IRunConfigurationFactory *i, rcFactories) {
             if (i->canCreate(this, id)) {
@@ -654,24 +662,26 @@ void Target::updateDefaultRunConfigurations()
     }
 
     // Do actual changes:
-    foreach (RunConfiguration *rc, toRemove) {
-        removeRunConfiguration(rc);
-        existingConfigured.removeOne(rc); // make sure to also remove them from existingConfigured!
-    }
-
-    if (removeExistingUnconfigured) {
-        foreach (RunConfiguration *rc, existingUnconfigured)
-            removeRunConfiguration(rc);
-        existingUnconfigured.clear();
-    }
-
     foreach (RunConfiguration *rc, newConfigured)
         addRunConfiguration(rc);
     foreach (RunConfiguration *rc, newUnconfigured)
         addRunConfiguration(rc);
 
-    // Make sure a configured RC is active:
-    if (activeRunConfiguration() && !activeRunConfiguration()->isConfigured()) {
+    // Generate complete list of RCs to remove later:
+    QList<RunConfiguration *> removalList;
+    foreach (RunConfiguration *rc, toRemove) {
+        removalList << rc;
+        existingConfigured.removeOne(rc); // make sure to also remove them from existingConfigured!
+    }
+
+    if (removeExistingUnconfigured) {
+        removalList.append(existingUnconfigured);
+        existingUnconfigured.clear();
+    }
+
+    // Make sure a configured RC will be active after we delete the RCs:
+    RunConfiguration *active = activeRunConfiguration();
+    if (removalList.contains(active)) {
         if (!existingConfigured.isEmpty()) {
             setActiveRunConfiguration(existingConfigured.at(0));
         } else if (!newConfigured.isEmpty()) {
@@ -685,8 +695,20 @@ void Target::updateDefaultRunConfigurations()
                 }
             }
             setActiveRunConfiguration(selected);
+        } else if (!newUnconfigured.isEmpty()){
+            setActiveRunConfiguration(newUnconfigured.at(0));
+        } else {
+            if (!removalList.isEmpty())
+                setActiveRunConfiguration(removalList.last());
+            // Nothing will be left after removal: We set this to the last of in the removal list
+            // since that gives us the minimum number of signals (one signal for the change here and
+            // one more when the last RC is removed and the active RC becomes 0).
         }
     }
+
+    // Remove the RCs that are no longer needed:
+    foreach (RunConfiguration *rc, removalList)
+        removeRunConfiguration(rc);
 }
 
 QVariant Target::namedSettings(const QString &name) const
