@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of Qt Creator.
@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -34,6 +35,7 @@
 #include "toolchainconfigwidget.h"
 #include "toolchainmanager.h"
 
+#include <coreplugin/icore.h>
 #include <extensionsystem/pluginmanager.h>
 
 #include <utils/detailswidget.h>
@@ -308,7 +310,7 @@ void ToolChainModel::apply()
     qDeleteAll(m_toAddList);
 
     if (removedTcs.count() == 1) {
-        QMessageBox::warning(0,
+        QMessageBox::warning(Core::ICore::dialogParent(),
                              tr("Duplicate Compilers Detected"),
                              tr("The following compiler was already configured:<br>"
                                 "&nbsp;%1<br>"
@@ -316,7 +318,7 @@ void ToolChainModel::apply()
                              .arg(removedTcs.at(0)));
 
     } else if (!removedTcs.isEmpty()) {
-        QMessageBox::warning(0,
+        QMessageBox::warning(Core::ICore::dialogParent(),
                              tr("Duplicate Compilers Detected"),
                              tr("The following compilers were already configured:<br>"
                                 "&nbsp;%1<br>"
@@ -450,64 +452,65 @@ ToolChainOptionsPage::ToolChainOptionsPage() :
     setCategoryIcon(QLatin1String(Constants::PROJECTEXPLORER_SETTINGS_CATEGORY_ICON));
 }
 
-QWidget *ToolChainOptionsPage::createPage(QWidget *parent)
+QWidget *ToolChainOptionsPage::widget()
 {
-    // Actual page setup:
-    m_configWidget = new QWidget(parent);
+    if (!m_configWidget) {
+        // Actual page setup:
+        m_configWidget = new QWidget;
 
-    m_toolChainView = new QTreeView(m_configWidget);
-    m_toolChainView->setUniformRowHeights(true);
-    m_toolChainView->header()->setStretchLastSection(false);
+        m_toolChainView = new QTreeView(m_configWidget);
+        m_toolChainView->setUniformRowHeights(true);
+        m_toolChainView->header()->setStretchLastSection(false);
 
-    m_addButton = new QPushButton(tr("Add"), m_configWidget);
-    m_cloneButton = new QPushButton(tr("Clone"), m_configWidget);
-    m_delButton = new QPushButton(tr("Remove"), m_configWidget);
+        m_addButton = new QPushButton(tr("Add"), m_configWidget);
+        m_cloneButton = new QPushButton(tr("Clone"), m_configWidget);
+        m_delButton = new QPushButton(tr("Remove"), m_configWidget);
 
-    m_container = new Utils::DetailsWidget(m_configWidget);
-    m_container->setState(Utils::DetailsWidget::NoSummary);
-    m_container->setVisible(false);
+        m_container = new Utils::DetailsWidget(m_configWidget);
+        m_container->setState(Utils::DetailsWidget::NoSummary);
+        m_container->setVisible(false);
 
-    QVBoxLayout *buttonLayout = new QVBoxLayout();
-    buttonLayout->setSpacing(6);
-    buttonLayout->setContentsMargins(0, 0, 0, 0);
-    buttonLayout->addWidget(m_addButton);
-    buttonLayout->addWidget(m_cloneButton);
-    buttonLayout->addWidget(m_delButton);
-    buttonLayout->addItem(new QSpacerItem(10, 40, QSizePolicy::Minimum, QSizePolicy::Expanding));
+        QVBoxLayout *buttonLayout = new QVBoxLayout();
+        buttonLayout->setSpacing(6);
+        buttonLayout->setContentsMargins(0, 0, 0, 0);
+        buttonLayout->addWidget(m_addButton);
+        buttonLayout->addWidget(m_cloneButton);
+        buttonLayout->addWidget(m_delButton);
+        buttonLayout->addItem(new QSpacerItem(10, 40, QSizePolicy::Minimum, QSizePolicy::Expanding));
 
-    QVBoxLayout *verticalLayout = new QVBoxLayout();
-    verticalLayout->addWidget(m_toolChainView);
-    verticalLayout->addWidget(m_container);
+        QVBoxLayout *verticalLayout = new QVBoxLayout();
+        verticalLayout->addWidget(m_toolChainView);
+        verticalLayout->addWidget(m_container);
 
-    QHBoxLayout *horizontalLayout = new QHBoxLayout(m_configWidget);
-    horizontalLayout->addLayout(verticalLayout);
-    horizontalLayout->addLayout(buttonLayout);
-    Q_ASSERT(!m_model);
-    m_model = new ToolChainModel(m_configWidget);
+        QHBoxLayout *horizontalLayout = new QHBoxLayout(m_configWidget);
+        horizontalLayout->addLayout(verticalLayout);
+        horizontalLayout->addLayout(buttonLayout);
+        Q_ASSERT(!m_model);
+        m_model = new ToolChainModel(m_configWidget);
 
-    connect(m_model, SIGNAL(toolChainStateChanged()), this, SLOT(updateState()));
+        connect(m_model, SIGNAL(toolChainStateChanged()), this, SLOT(updateState()));
 
-    m_toolChainView->setModel(m_model);
-    m_toolChainView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
-    m_toolChainView->header()->setResizeMode(1, QHeaderView::Stretch);
-    m_toolChainView->expandAll();
+        m_toolChainView->setModel(m_model);
+        m_toolChainView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+        m_toolChainView->header()->setResizeMode(1, QHeaderView::Stretch);
+        m_toolChainView->expandAll();
 
-    m_selectionModel = m_toolChainView->selectionModel();
-    connect(m_selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(toolChainSelectionChanged()));
-    connect(ToolChainManager::instance(), SIGNAL(toolChainsChanged()),
-            this, SLOT(toolChainSelectionChanged()));
+        m_selectionModel = m_toolChainView->selectionModel();
+        connect(m_selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+                this, SLOT(toolChainSelectionChanged()));
+        connect(ToolChainManager::instance(), SIGNAL(toolChainsChanged()),
+                this, SLOT(toolChainSelectionChanged()));
 
-    // Get toolchainfactories:
-    m_factories = ExtensionSystem::PluginManager::getObjects<ToolChainFactory>();
+        // Get toolchainfactories:
+        m_factories = ExtensionSystem::PluginManager::getObjects<ToolChainFactory>(
+                    [](ToolChainFactory *factory) { return factory->canCreate();});
 
-    // Set up add menu:
-    QMenu *addMenu = new QMenu(m_addButton);
-    QSignalMapper *mapper = new QSignalMapper(addMenu);
-    connect(mapper, SIGNAL(mapped(QObject*)), this, SLOT(createToolChain(QObject*)));
+        // Set up add menu:
+        QMenu *addMenu = new QMenu(m_addButton);
+        QSignalMapper *mapper = new QSignalMapper(addMenu);
+        connect(mapper, SIGNAL(mapped(QObject*)), this, SLOT(createToolChain(QObject*)));
 
-    foreach (ToolChainFactory *factory, m_factories) {
-        if (factory->canCreate()) {
+        foreach (ToolChainFactory *factory, m_factories) {
             QAction *action = new QAction(addMenu);
             action->setText(factory->displayName());
             connect(action, SIGNAL(triggered()), mapper, SLOT(map()));
@@ -515,27 +518,14 @@ QWidget *ToolChainOptionsPage::createPage(QWidget *parent)
 
             addMenu->addAction(action);
         }
+        connect(m_cloneButton, SIGNAL(clicked()), mapper, SLOT(map()));
+        mapper->setMapping(m_cloneButton, static_cast<QObject *>(0));
+
+        m_addButton->setMenu(addMenu);
+
+        connect(m_delButton, SIGNAL(clicked()), this, SLOT(removeToolChain()));
+        updateState();
     }
-    connect(m_cloneButton, SIGNAL(clicked()), mapper, SLOT(map()));
-    mapper->setMapping(m_cloneButton, static_cast<QObject *>(0));
-
-    m_addButton->setMenu(addMenu);
-
-    connect(m_delButton, SIGNAL(clicked()), this, SLOT(removeToolChain()));
-
-    // setup keywords:
-    if (m_searchKeywords.isEmpty()) {
-        QLatin1Char sep(' ');
-        QTextStream stream(&m_searchKeywords);
-        stream << tr("Compilers");
-        foreach (ToolChainFactory *f, m_factories)
-            stream << sep << f->displayName();
-
-        m_searchKeywords.remove(QLatin1Char('&'));
-    }
-
-    updateState();
-
     return m_configWidget;
 }
 
@@ -550,8 +540,7 @@ void ToolChainOptionsPage::finish()
     disconnect(ToolChainManager::instance(), SIGNAL(toolChainsChanged()),
                this, SLOT(toolChainSelectionChanged()));
 
-    // delete by settingsdialog;
-    m_configWidget = 0;
+    delete m_configWidget;
 
     // children of m_configWidget
     m_model = 0;
@@ -563,11 +552,6 @@ void ToolChainOptionsPage::finish()
     m_delButton = 0;
 }
 
-bool ToolChainOptionsPage::matches(const QString &s) const
-{
-    return m_searchKeywords.contains(s, Qt::CaseInsensitive);
-}
-
 void ToolChainOptionsPage::toolChainSelectionChanged()
 {
     if (!m_container)
