@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -36,8 +37,6 @@
 
 #include <QIcon>
 
-namespace qbs { class Project; }
-
 namespace QbsProjectManager {
 namespace Internal {
 
@@ -57,8 +56,6 @@ public:
                 int line);
 
     QString displayName() const;
-
-    bool update(const qbs::CodeLocation &loc);
 };
 
 // ---------------------------------------------------------------------------
@@ -89,8 +86,6 @@ public:
     bool deleteFiles(const QStringList &filePaths);
     bool renameFile(const QString &filePath, const QString &newFilePath);
 
-    QList<ProjectExplorer::RunConfiguration *> runConfigurationsFor(Node *node);
-
 private:
     friend class QbsGroupNode;
 };
@@ -107,6 +102,9 @@ public:
     QbsGroupNode(const qbs::GroupData *grp, const QString &productPath);
 
     bool isEnabled() const;
+    QList<ProjectExplorer::ProjectAction> supportedActions(Node *node) const;
+    bool addFiles(const QStringList &filePaths, QStringList *notAdded = 0);
+    bool removeFiles(const QStringList &filePaths, QStringList *notRemoved = 0);
     void updateQbsGroupData(const qbs::GroupData *grp, const QString &productPath,
                             bool productWasEnabled, bool productIsEnabled);
 
@@ -114,7 +112,7 @@ public:
 
     QString productPath() const;
 
-    static void setupFiles(QbsBaseProjectNode *root, const QStringList &files,
+    static void setupFiles(FolderNode *root, const QStringList &files,
                            const QString &productPath, bool updateExisting);
 
 private:
@@ -139,11 +137,14 @@ public:
 
     bool isEnabled() const;
     bool showInSimpleTree() const;
+    QList<ProjectExplorer::ProjectAction> supportedActions(Node *node) const;
+    bool addFiles(const QStringList &filePaths, QStringList *notAdded = 0);
+    bool removeFiles(const QStringList &filePaths, QStringList *notRemoved = 0);
 
     void setQbsProductData(const qbs::ProductData prd);
     const qbs::ProductData qbsProductData() const { return m_qbsProductData; }
 
-    QList<ProjectExplorer::RunConfiguration *> runConfigurationsFor(Node *node);
+    QList<ProjectExplorer::RunConfiguration *> runConfigurations() const;
 
 private:
     QbsGroupNode *findGroupNode(const QString &name);
@@ -161,30 +162,54 @@ class QbsProjectNode : public QbsBaseProjectNode
     Q_OBJECT
 
 public:
-    explicit QbsProjectNode(QbsProject *project);
     explicit QbsProjectNode(const QString &path);
     ~QbsProjectNode();
 
-    void update(const qbs::Project &prj);
-    void update(const qbs::ProjectData &prjData);
+    bool addFiles(const QStringList &filePaths, QStringList *notAdded = 0);
 
-    QbsProject *project() const;
+    virtual QbsProject *project() const;
     const qbs::Project qbsProject() const;
-    const qbs::ProjectData qbsProjectData() const;
+    const qbs::ProjectData qbsProjectData() const { return m_projectData; }
 
     bool showInSimpleTree() const;
+
+protected:
+    void update(const qbs::ProjectData &prjData);
+
 private:
     void ctor();
 
     QbsProductNode *findProductNode(const QString &name);
     QbsProjectNode *findProjectNode(const QString &name);
 
-    QbsProject *m_project;
-
-    qbs::Project m_qbsProject;
-    qbs::ProjectData m_qbsProjectData;
     static QIcon m_projectIcon;
+    qbs::ProjectData m_projectData;
 };
+
+// --------------------------------------------------------------------
+// QbsRootProjectNode:
+// --------------------------------------------------------------------
+
+class QbsRootProjectNode : public QbsProjectNode
+{
+    Q_OBJECT
+
+public:
+    explicit QbsRootProjectNode(QbsProject *project);
+
+    using QbsProjectNode::update;
+    void update();
+
+    QbsProject *project() const { return m_project; }
+
+private:
+    QStringList unreferencedBuildSystemFiles(const qbs::Project &p) const;
+
+    QbsProject * const m_project;
+    ProjectExplorer::FolderNode *m_buildSystemFiles;
+};
+
+
 } // namespace Internal
 } // namespace QbsProjectManager
 
