@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -39,6 +40,9 @@
 #include <coreplugin/documentmanager.h>
 #include <coreplugin/icontext.h>
 #include <coreplugin/id.h>
+#include <coreplugin/icore.h>
+#include <coreplugin/iversioncontrol.h>
+#include <coreplugin/vcsmanager.h>
 #include <coreplugin/messagemanager.h>
 #include <coreplugin/progressmanager/progressmanager.h>
 #include <coreplugin/mimedatabase.h>
@@ -68,6 +72,7 @@
 #include <QCoreApplication>
 #include <QDir>
 #include <QFileInfo>
+#include <QMessageBox>
 #include <QVariantMap>
 
 using namespace Core;
@@ -131,6 +136,11 @@ QbsProject::~QbsProject()
 {
     m_codeModelFuture.cancel();
     delete m_qbsProjectParser;
+    if (m_qbsUpdateFutureInterface) {
+        m_qbsUpdateFutureInterface->reportCanceled();
+        delete m_qbsUpdateFutureInterface;
+        m_qbsUpdateFutureInterface = 0;
+    }
 
     // Deleting the root node triggers a few things, make sure rootProjectNode
     // returns 0 already
@@ -181,11 +191,11 @@ static void collectFilesForProject(const qbs::ProjectData &project, QSet<QString
 QStringList QbsProject::files(Project::FilesMode fileMode) const
 {
     Q_UNUSED(fileMode);
-    if (!m_rootProjectNode || !m_rootProjectNode->qbsProjectData().isValid())
+    if (!m_qbsProject.isValid() || isParsing())
         return QStringList();
     QSet<QString> result;
-    collectFilesForProject(m_rootProjectNode->qbsProjectData(), result);
-    result.unite(qbsProject().buildSystemFiles());
+    collectFilesForProject(m_projectData, result);
+    result.unite(m_qbsProject.buildSystemFiles());
     return result.toList();
 }
 
@@ -224,6 +234,27 @@ private:
     bool m_wasInDocumentManager;
 };
 
+bool QbsProject::ensureWriteableQbsFile(const QString &file)
+{
+    // Ensure that the file is not read only
+    QFileInfo fi(file);
+    if (!fi.isWritable()) {
+        // Try via vcs manager
+        Core::IVersionControl *versionControl =
+            Core::VcsManager::findVersionControlForDirectory(fi.absolutePath());
+        if (!versionControl || !versionControl->vcsOpen(file)) {
+            bool makeWritable = QFile::setPermissions(file, fi.permissions() | QFile::WriteUser);
+            if (!makeWritable) {
+                QMessageBox::warning(Core::ICore::mainWindow(),
+                                     tr("Failed!"),
+                                     tr("Could not write project file %1.").arg(file));
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
 bool QbsProject::addFilesToProduct(QbsBaseProjectNode *node, const QStringList &filePaths,
         const qbs::ProductData &productData, const qbs::GroupData &groupData, QStringList *notAdded)
 {
@@ -231,6 +262,7 @@ bool QbsProject::addFilesToProduct(QbsBaseProjectNode *node, const QStringList &
     QStringList allPaths = groupData.allFilePaths();
     const QString productFilePath = productData.location().fileName();
     ChangeExpector expector(productFilePath, m_qbsDocuments);
+    ensureWriteableQbsFile(productFilePath);
     foreach (const QString &path, filePaths) {
         qbs::ErrorInfo err = m_qbsProject.addFiles(productData, groupData, QStringList() << path);
         if (err.hasError()) {
@@ -256,6 +288,7 @@ bool QbsProject::removeFilesFromProduct(QbsBaseProjectNode *node, const QStringL
     QStringList allPaths = groupData.allFilePaths();
     const QString productFilePath = productData.location().fileName();
     ChangeExpector expector(productFilePath, m_qbsDocuments);
+    ensureWriteableQbsFile(productFilePath);
     foreach (const QString &path, filePaths) {
         qbs::ErrorInfo err
                 = m_qbsProject.removeFiles(productData, groupData, QStringList() << path);
