@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -44,6 +45,7 @@
 #include <projectexplorer/project.h>
 #include <projectexplorer/target.h>
 #include <projectexplorer/session.h>
+#include <projectexplorer/kit.h>
 #include <qtsupport/qtkitinformation.h>
 #include <qtsupport/qtsupportconstants.h>
 #include <qtsupport/qtversionmanager.h>
@@ -74,7 +76,7 @@ DesignDocument::DesignDocument(QObject *parent) :
         m_subComponentManager(new SubComponentManager(m_documentModel.data(), this)),
         m_rewriterView (new RewriterView(RewriterView::Amend, m_documentModel.data())),
         m_documentLoaded(false),
-        m_qtVersionId(-1)
+        m_currentKit(0)
 {
 }
 
@@ -100,17 +102,6 @@ QWidget *DesignDocument::centralWidget() const
     return qobject_cast<QWidget*>(parent());
 }
 
-QString DesignDocument::pathToQt() const
-{
-    QtSupport::BaseQtVersion *activeQtVersion = QtSupport::QtVersionManager::version(m_qtVersionId);
-    if (activeQtVersion && (activeQtVersion->qtVersion() >= QtSupport::QtVersionNumber(4, 7, 1))
-            && (activeQtVersion->type() == QLatin1String(QtSupport::Constants::DESKTOPQT)
-                || activeQtVersion->type() == QLatin1String(QtSupport::Constants::SIMULATORQT)))
-        return activeQtVersion->qmakeProperty("QT_INSTALL_DATA");
-
-    return QString();
-}
-
 const ViewManager &DesignDocument::viewManager() const
 {
     return QmlDesignerPlugin::instance()->viewManager();
@@ -161,7 +152,7 @@ bool DesignDocument::loadInFileComponent(const ModelNode &componentNode)
     return true;
 }
 
-AbstractView *DesignDocument::view()
+AbstractView *DesignDocument::view() const
 {
     return viewManager().nodeInstanceView();
 }
@@ -221,9 +212,9 @@ QString DesignDocument::fileName() const
     return editor()->document()->filePath();
 }
 
-int DesignDocument::qtVersionId() const
+ProjectExplorer::Kit *DesignDocument::currentKit() const
 {
-    return m_qtVersionId;
+    return m_currentKit;
 }
 
 bool DesignDocument::isDocumentLoaded() const
@@ -254,8 +245,6 @@ void DesignDocument::loadDocument(QPlainTextEdit *edit)
 
     updateFileName(QString(), fileName());
 
-    m_subComponentManager->update(QUrl::fromLocalFile(fileName()), currentModel()->imports());
-
     m_documentLoaded = true;
 }
 
@@ -411,11 +400,11 @@ void DesignDocument::copySelected()
         currentModel()->detachView(&view);
         copyModel->attachView(&view);
 
-        foreach (ModelNode node, view.rootModelNode().allDirectSubModelNodes()) {
+        foreach (ModelNode node, view.rootModelNode().directSubModelNodes()) {
             node.destroy();
         }
         view.changeRootNodeType("QtQuick.Rectangle", 1, 0);
-        view.rootModelNode().setId("designer__Selection");
+        view.rootModelNode().setIdWithRefactoring("designer__Selection");
 
         foreach (const ModelNode &selectedNode, selectedNodes) {
             ModelNode newNode(view.insertModel(selectedNode));
@@ -432,11 +421,13 @@ void DesignDocument::cutSelected()
     deleteSelected();
 }
 
-static void scatterItem(ModelNode pastedNode, const ModelNode targetNode, int offset = -2000)
+static void scatterItem(const ModelNode &pastedNode, const ModelNode &targetNode, int offset = -2000)
 {
+    if (targetNode.metaInfo().isValid() && targetNode.metaInfo().isLayoutable())
+        return;
 
     bool scatter = false;
-    foreach (const ModelNode &childNode, targetNode.allDirectSubModelNodes()) {
+    foreach (const ModelNode &childNode, targetNode.directSubModelNodes()) {
         if ((childNode.variantProperty("x").value() == pastedNode.variantProperty("x").value()) &&
             (childNode.variantProperty("y").value() == pastedNode.variantProperty("y").value()))
             scatter = true;
@@ -485,7 +476,7 @@ void DesignDocument::paste()
         return;
 
     if (rootNode.id() == "designer__Selection") {
-        QList<ModelNode> selectedNodes = rootNode.allDirectSubModelNodes();
+        QList<ModelNode> selectedNodes = rootNode.directSubModelNodes();
         pasteModel->detachView(&view);
         currentModel()->attachView(&view);
 
@@ -646,7 +637,7 @@ static bool isFileInProject(DesignDocument *designDocument, ProjectExplorer::Pro
     return false;
 }
 
-static inline QtSupport::BaseQtVersion *getActiveQtVersion(DesignDocument *designDocument)
+static inline ProjectExplorer::Kit *getActiveKit(DesignDocument *designDocument)
 {
     ProjectExplorer::ProjectExplorerPlugin *projectExplorer = ProjectExplorer::ProjectExplorerPlugin::instance();
     ProjectExplorer::Project *currentProject = projectExplorer->currentProject();
@@ -660,10 +651,9 @@ static inline QtSupport::BaseQtVersion *getActiveQtVersion(DesignDocument *desig
     if (!isFileInProject(designDocument, currentProject))
         return 0;
 
-    designDocument->disconnect(designDocument,  SLOT(updateActiveQtVersion()));
-    designDocument->connect(projectExplorer, SIGNAL(currentProjectChanged(ProjectExplorer::Project*)), designDocument, SLOT(updateActiveQtVersion()));
+    designDocument->connect(projectExplorer, SIGNAL(currentProjectChanged(ProjectExplorer::Project*)), designDocument, SLOT(updateActiveQtVersion()), Qt::UniqueConnection);
 
-    designDocument->connect(currentProject, SIGNAL(activeTargetChanged(ProjectExplorer::Target*)), designDocument, SLOT(updateActiveQtVersion()));
+    designDocument->connect(currentProject, SIGNAL(activeTargetChanged(ProjectExplorer::Target*)), designDocument, SLOT(updateActiveQtVersion()), Qt::UniqueConnection);
 
 
     ProjectExplorer::Target *target = currentProject->activeTarget();
@@ -671,40 +661,23 @@ static inline QtSupport::BaseQtVersion *getActiveQtVersion(DesignDocument *desig
     if (!target)
         return 0;
 
-    designDocument->connect(target, SIGNAL(kitChanged()), designDocument, SLOT(updateActiveQtVersion()));
-    return QtSupport::QtKitInformation::qtVersion(target->kit());
+    designDocument->connect(target, SIGNAL(kitChanged()), designDocument, SLOT(updateActiveQtVersion()), Qt::UniqueConnection);
+
+    return target->kit();
 }
 
 void DesignDocument::updateActiveQtVersion()
 {
-    QtSupport::BaseQtVersion *newQtVersion = getActiveQtVersion(this);
-
-    if (!newQtVersion ) {
-        m_qtVersionId = -1;
-        return;
-    }
-
-    if (m_qtVersionId == newQtVersion->uniqueId())
-        return;
-
-    m_qtVersionId = newQtVersion->uniqueId();
-
-    viewManager().setNodeInstanceViewQtPath(pathToQt());
+    m_currentKit = getActiveKit(this);
+    viewManager().setNodeInstanceViewKit(m_currentKit);
 }
 
 QString DesignDocument::contextHelpId() const
 {
-    DesignDocumentView view;
-    currentModel()->attachView(&view);
+    if (view())
+        view()->contextHelpId();
 
-    QList<ModelNode> nodes = view.selectedModelNodes();
-    QString helpId;
-    if (!nodes.isEmpty()) {
-        helpId = nodes.first().type();
-        helpId.replace("QtQuick", "QML");
-    }
-
-    return helpId;
+    return QString();
 }
 
 } // namespace QmlDesigner
