@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -232,8 +233,8 @@ void DesignModeWidget::readSettings()
     QSettings *settings = Core::ICore::settings();
 
     settings->beginGroup("Bauhaus");
-    m_leftSideBar->readSettings(settings, QLatin1String("LeftSideBar"));
-    m_rightSideBar->readSettings(settings, QLatin1String("RightSideBar"));
+    m_leftSideBar->readSettings(settings, QStringLiteral("LeftSideBar"));
+    m_rightSideBar->readSettings(settings, QStringLiteral("RightSideBar"));
     if (settings->contains("MainSplitter")) {
         const QByteArray splitterState = settings->value("MainSplitter").toByteArray();
         m_mainSplitter->restoreState(splitterState);
@@ -247,8 +248,8 @@ void DesignModeWidget::saveSettings()
     QSettings *settings = Core::ICore::settings();
 
     settings->beginGroup("Bauhaus");
-    m_leftSideBar->saveSettings(settings, QLatin1String("LeftSideBar"));
-    m_rightSideBar->saveSettings(settings, QLatin1String("RightSideBar"));
+    m_leftSideBar->saveSettings(settings, QStringLiteral("LeftSideBar"));
+    m_rightSideBar->saveSettings(settings, QStringLiteral("RightSideBar"));
     settings->setValue("MainSplitter", m_mainSplitter->saveState());
     settings->endGroup();
 }
@@ -428,8 +429,8 @@ void DesignModeWidget::setup()
     viewManager().enableWidgets();
     m_leftSideBar->setEnabled(true);
     m_rightSideBar->setEnabled(true);
-    m_leftSideBar->setCloseWhenEmpty(true);
-    m_rightSideBar->setCloseWhenEmpty(true);
+    m_leftSideBar->setCloseWhenEmpty(false);
+    m_rightSideBar->setCloseWhenEmpty(false);
 
     readSettings();
 
@@ -498,8 +499,10 @@ ViewManager &DesignModeWidget::viewManager()
 
 void DesignModeWidget::resizeEvent(QResizeEvent *event)
 {
-    if (m_warningWidget)
-        m_warningWidget->move(QPoint(event->size().width() / 2, event->size().height() / 2));
+    if (m_warningWidget) {
+        QPoint warningWidgetCenterPoint = m_warningWidget->rect().center();
+        m_warningWidget->move(QPoint(event->size().width() / 2, event->size().height() / 2) - warningWidgetCenterPoint);
+    }
     QWidget::resizeEvent(event);
 }
 
