@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -208,7 +209,7 @@ AnalyzerRunControl *QmlProfilerTool::createRunControl(const AnalyzerStartParamet
     QString projectDirectory;
     if (runConfiguration) {
         Project *project = runConfiguration->target()->project();
-        projectDirectory = project->projectDirectory();
+        projectDirectory = project->projectDirectory().toString();
     }
 
     populateFileFinder(projectDirectory, sp.sysroot);
@@ -298,7 +299,7 @@ void QmlProfilerTool::populateFileFinder(QString projectDirectory, QString activ
 
     if (!projects.isEmpty()) {
         if (projectDirectory.isEmpty())
-            projectDirectory = projects.first()->projectDirectory();
+            projectDirectory = projects.first()->projectDirectory().toString();
 
         if (activeSysroot.isEmpty()) {
             if (Target *target = projects.first()->activeTarget())
@@ -448,7 +449,7 @@ void QmlProfilerTool::startTool(StartMode mode)
     }
 }
 
-void QmlProfilerTool::logStatus(const QString &msg)
+void QmlProfilerTool::logState(const QString &msg)
 {
     MessageManager::write(msg, Core::MessageManager::Flash);
 }
