@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -56,7 +57,7 @@ using namespace Internal;
 namespace {
 
 template <class T>
-void filterEditorSpecificProviders(QList<T *> *providers, const Core::Id &editorId)
+void filterEditorSpecificProviders(QList<T *> *providers, Core::Id editorId)
 {
     typename QList<T *>::iterator it = providers->begin();
     while (it != providers->end()) {
@@ -182,7 +183,7 @@ void CodeAssistantPrivate::configure(BaseTextEditor *textEditor)
     m_completionProvider = textEditor->completionAssistProvider();
     m_quickFixProviders =
         ExtensionSystem::PluginManager::getObjects<QuickFixAssistProvider>();
-    filterEditorSpecificProviders(&m_quickFixProviders, m_textEditor->id());
+    filterEditorSpecificProviders(&m_quickFixProviders, m_textEditor->document()->id());
 
     m_textEditor->editorWidget()->installEventFilter(this);
     connect(m_textEditor->baseTextDocument(),SIGNAL(mimeTypeChanged()),
@@ -248,6 +249,9 @@ void CodeAssistantPrivate::requestProposal(AssistReason reason,
 {
     QTC_ASSERT(!isWaitingForProposal(), return);
 
+    if (m_textEditor->editorWidget()->hasBlockSelection())
+        return; // TODO
+
     if (!provider) {
         if (kind == Completion)
             provider = m_completionProvider;
