@@ -10,16 +10,17 @@
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** conditions see http://www.qt.io/licensing.  For further information
+** use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
 ** rights.  These rights are described in the Digia Qt LGPL Exception
@@ -27,6 +28,8 @@
 **
 ****************************************************************************/
 
+#include "../cplusplus_global.h"
+
 #include <QtTest>
 #include <QObject>
 #include <QList>
@@ -111,6 +114,10 @@ private Q_SLOTS:
     void templatedFunction_QTCREATORBUG9749();
 
     void usingInDifferentNamespace_QTCREATORBUG7978();
+
+    void unicodeIdentifier();
+
+    void inAlignas();
 };
 
 void tst_FindUsages::dump(const QList<Usage> &usages) const
@@ -951,5 +958,65 @@ void tst_FindUsages::usingInDifferentNamespace_QTCREATORBUG7978()
     QCOMPARE(findUsages.usages().size(), 3);
 }
 
+void tst_FindUsages::unicodeIdentifier()
+{
+    const QByteArray src = "\n"
+            "int var" TEST_UNICODE_IDENTIFIER ";\n"
+            "void f() { var" TEST_UNICODE_IDENTIFIER " = 1; }\n";
+            ;
+
+    Document::Ptr doc = Document::create("u");
+    doc->setUtf8Source(src);
+    doc->parse();
+    doc->check();
+
+    QVERIFY(doc->diagnosticMessages().isEmpty());
+    QCOMPARE(doc->globalSymbolCount(), 2U);
+
+    Snapshot snapshot;
+    snapshot.insert(doc);
+
+    Declaration *declaration = doc->globalSymbolAt(0)->asDeclaration();
+    QVERIFY(declaration);
+
+    FindUsages findUsages(src, doc, snapshot);
+    findUsages(declaration);
+    const QList<Usage> usages = findUsages.usages();
+    QCOMPARE(usages.size(), 2);
+    QCOMPARE(usages.at(0).len, 7);
+    QCOMPARE(usages.at(1).len, 7);
+}
+
+void tst_FindUsages::inAlignas()
+{
+    const QByteArray src = "\n"
+            "struct One {};\n"
+            "struct alignas(One) Two {};\n"
+            ;
+
+    Document::Ptr doc = Document::create("inAlignas");
+    doc->setUtf8Source(src);
+    doc->parse();
+    doc->check();
+
+    QVERIFY(doc->diagnosticMessages().isEmpty());
+    QCOMPARE(doc->globalSymbolCount(), 2U);
+
+    Snapshot snapshot;
+    snapshot.insert(doc);
+
+    Class *c = doc->globalSymbolAt(0)->asClass();
+    QVERIFY(c);
+    QCOMPARE(c->name()->identifier()->chars(), "One");
+
+    FindUsages find(src, doc, snapshot);
+    find(c);
+    QCOMPARE(find.usages().size(), 2);
+    QCOMPARE(find.usages()[0].line, 1);
+    QCOMPARE(find.usages()[0].col, 7);
+    QCOMPARE(find.usages()[1].line, 2);
+    QCOMPARE(find.usages()[1].col, 15);
+}
+
 QTEST_APPLESS_MAIN(tst_FindUsages)
 #include "tst_findusages.moc"
